==> alg-alg-1.32.0-sources.jar: cn/com/duiba/nezha/alg/alg/vo/title/ActTitleRcmdDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.title;

import cn.com.duiba.nezha.alg.alg.vo.plug.ResPlugInStatDo;

import java.io.Serializable;

/**
 * 响应插件-推荐对象
 */
public class ActTitleRcmdDo implements Serializable {



    private String key ;

    private Long activityTitleId; //主标题ID.请求

    private Long activitySubTitleId; //副标题ID.请求


    private Long isNew;//主标题是否新增

    private Long subIsNew;//副标题是否新增

    private Integer type; //标题的海选类型

    private Double score;// 精排-排序分

    private Long rank;// 精排-排序


    private Boolean hasSubTitle;

    private Boolean hasType; //标题的海选类型, 1：活动海选  2：皮肤海选  3、广告位皮肤海选

    private Double score1;// 海选排序分,type=1
    private Long rank1;// 海选排序,type=1

    private Double score2;// 海选排序分,type=1
    private Long rank2;// 海选排序,type=1

    private Double score3;// 海选排序分,type=1
    private Long rank3;// 海选排序,type=1

    private Double mergeRpm;//统计融合RPM(主+副)

    private Double pRpm;//预估RPM(主+副)

    private Double sRpm;//主标题统计RPM
    private Double jpv;//主标题每访问复参数
    private Double cpv;//主标题每访问复点击数
    private Double apv;//主标题每访问复点转化数


    private Double subSRpm;//副标题统计RPM
    private Double subJpv;//副标题每访问复参数
    private Double subCpv;//副标题每访问复点击数
    private Double subApv;//副标题每访问复点转化数


    public Long getActivityTitleId() {
        return activityTitleId;
    }

    public void setActivityTitleId(Long activityTitleId) {
        this.activityTitleId = activityTitleId;
    }

    public Long getActivitySubTitleId() {
        return activitySubTitleId;
    }

    public void setActivitySubTitleId(Long activitySubTitleId) {
        this.activitySubTitleId = activitySubTitleId;
    }

    public Long getIsNew() {
        return isNew;
    }

    public void setIsNew(Long isNew) {
        this.isNew = isNew;
    }

    public Long getSubIsNew() {
        return subIsNew;
    }

    public void setSubIsNew(Long subIsNew) {
        this.subIsNew = subIsNew;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Double getScore() {
        return score;
    }

    public void setScore(Double score) {
        this.score = score;
    }

    public Long getRank() {
        return rank;
    }

    public void setRank(Long rank) {
        this.rank = rank;
    }

    public Double getsRpm() {
        return sRpm;
    }

    public void setsRpm(Double sRpm) {
        this.sRpm = sRpm;
    }

    public Double getpRpm() {
        return pRpm;
    }

    public void setpRpm(Double pRpm) {
        this.pRpm = pRpm;
    }

    public Double getJpv() {
        return jpv;
    }

    public void setJpv(Double jpv) {
        this.jpv = jpv;
    }

    public Double getCpv() {
        return cpv;
    }

    public void setCpv(Double cpv) {
        this.cpv = cpv;
    }

    public Double getApv() {
        return apv;
    }

    public void setApv(Double apv) {
        this.apv = apv;
    }


    public Boolean getHasType() {
        return hasType;
    }

    public void setHasType(Boolean hasType) {
        this.hasType = hasType;
    }

    public Double getScore1() {
        return score1;
    }

    public void setScore1(Double score1) {
        this.score1 = score1;
    }

    public Long getRank1() {
        return rank1;
    }

    public void setRank1(Long rank1) {
        this.rank1 = rank1;
    }

    public Double getScore2() {
        return score2;
    }

    public void setScore2(Double score2) {
        this.score2 = score2;
    }

    public Long getRank2() {
        return rank2;
    }

    public void setRank2(Long rank2) {
        this.rank2 = rank2;
    }

    public Double getScore3() {
        return score3;
    }

    public void setScore3(Double score3) {
        this.score3 = score3;
    }

    public Long getRank3() {
        return rank3;
    }

    public void setRank3(Long rank3) {
        this.rank3 = rank3;
    }


    public Double getMergeRpm() {
        return mergeRpm;
    }

    public void setMergeRpm(Double mergeRpm) {
        this.mergeRpm = mergeRpm;
    }

    public Double getSubSRpm() {
        return subSRpm;
    }

    public void setSubSRpm(Double subSRpm) {
        this.subSRpm = subSRpm;
    }

    public Double getSubJpv() {
        return subJpv;
    }

    public void setSubJpv(Double subJpv) {
        this.subJpv = subJpv;
    }

    public Double getSubCpv() {
        return subCpv;
    }

    public void setSubCpv(Double subCpv) {
        this.subCpv = subCpv;
    }

    public Double getSubApv() {
        return subApv;
    }

    public void setSubApv(Double subApv) {
        this.subApv = subApv;
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }
}

==> alg-alg-1.43.13-20201203.133001-1-sources.jar: cn/com/duiba/nezha/alg/alg/vo/title/ActTitleRcmdDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.title;

import cn.com.duiba.nezha.alg.alg.vo.plug.ResPlugInStatDo;

import java.io.Serializable;
import java.util.Map;

/**
 * 响应插件-推荐对象
 */
public class ActTitleRcmdDo implements Serializable {



    private String key ;

    private Long activityTitleId; //主标题ID.请求

    private Long activitySubTitleId; //副标题ID.请求


    private Long isNew;//主标题是否新增

    private Long subIsNew;//副标题是否新增

    private Integer type; //标题的海选类型

    private Double score;// 精排-排序分

    private Long rank;// 精排-排序


    private Boolean hasSubTitle;

    private Boolean hasType; //标题的海选类型, 1：活动海选  2：皮肤海选  3、广告位皮肤海选

    private Double score1;// 海选排序分,type=1
    private Long rank1;// 海选排序,type=1

    private Double score2;// 海选排序分,type=1
    private Long rank2;// 海选排序,type=1

    private Double score3;// 海选排序分,type=1
    private Long rank3;// 海选排序,type=1

    private Double mergeRpm;//统计融合RPM(主+副)

    private Double pRpm;//预估RPM(主+副)

    private Double pPrizeRpm;//奖品预估每访问点击

    private Double sRpm;//主标题统计RPM
    private Double jpv;//主标题每访问复参数
    private Double cpv;//主标题每访问复点击数
    private Double apv;//主标题每访问复点转化数


    private Double subSRpm;//副标题统计RPM
    private Double subJpv;//副标题每访问复参数
    private Double subCpv;//副标题每访问复点击数
    private Double subApv;//副标题每访问复点转化数

    private Map<String,String>  featureMap;//特征Map


    private Long  activitySubTitlePrizeId ;//副标题奖品ID

    public Long getActivityTitleId() {
        return activityTitleId;
    }

    public void setActivityTitleId(Long activityTitleId) {
        this.activityTitleId = activityTitleId;
    }

    public Long getActivitySubTitleId() {
        return activitySubTitleId;
    }

    public void setActivitySubTitleId(Long activitySubTitleId) {
        this.activitySubTitleId = activitySubTitleId;
    }

    public Long getIsNew() {
        return isNew;
    }

    public void setIsNew(Long isNew) {
        this.isNew = isNew;
    }

    public Long getSubIsNew() {
        return subIsNew;
    }

    public void setSubIsNew(Long subIsNew) {
        this.subIsNew = subIsNew;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Double getScore() {
        return score;
    }

    public void setScore(Double score) {
        this.score = score;
    }

    public Long getRank() {
        return rank;
    }

    public void setRank(Long rank) {
        this.rank = rank;
    }

    public Double getsRpm() {
        return sRpm;
    }

    public void setsRpm(Double sRpm) {
        this.sRpm = sRpm;
    }

    public Double getpRpm() {
        return pRpm;
    }

    public void setpRpm(Double pRpm) {
        this.pRpm = pRpm;
    }

    public Double getJpv() {
        return jpv;
    }

    public void setJpv(Double jpv) {
        this.jpv = jpv;
    }

    public Double getCpv() {
        return cpv;
    }

    public void setCpv(Double cpv) {
        this.cpv = cpv;
    }

    public Double getApv() {
        return apv;
    }

    public void setApv(Double apv) {
        this.apv = apv;
    }


    public Boolean getHasType() {
        return hasType;
    }

    public void setHasType(Boolean hasType) {
        this.hasType = hasType;
    }

    public Double getScore1() {
        return score1;
    }

    public void setScore1(Double score1) {
        this.score1 = score1;
    }

    public Long getRank1() {
        return rank1;
    }

    public void setRank1(Long rank1) {
        this.rank1 = rank1;
    }

    public Double getScore2() {
        return score2;
    }

    public void setScore2(Double score2) {
        this.score2 = score2;
    }

    public Long getRank2() {
        return rank2;
    }

    public void setRank2(Long rank2) {
        this.rank2 = rank2;
    }

    public Double getScore3() {
        return score3;
    }

    public void setScore3(Double score3) {
        this.score3 = score3;
    }

    public Long getRank3() {
        return rank3;
    }

    public void setRank3(Long rank3) {
        this.rank3 = rank3;
    }


    public Double getMergeRpm() {
        return mergeRpm;
    }

    public void setMergeRpm(Double mergeRpm) {
        this.mergeRpm = mergeRpm;
    }

    public Double getSubSRpm() {
        return subSRpm;
    }

    public void setSubSRpm(Double subSRpm) {
        this.subSRpm = subSRpm;
    }

    public Double getSubJpv() {
        return subJpv;
    }

    public void setSubJpv(Double subJpv) {
        this.subJpv = subJpv;
    }

    public Double getSubCpv() {
        return subCpv;
    }

    public void setSubCpv(Double subCpv) {
        this.subCpv = subCpv;
    }

    public Double getSubApv() {
        return subApv;
    }

    public void setSubApv(Double subApv) {
        this.subApv = subApv;
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public Map<String, String> getFeatureMap() {
        return featureMap;
    }

    public void setFeatureMap(Map<String, String> featureMap) {
        this.featureMap = featureMap;
    }

    public Long getActivitySubTitlePrizeId() {
        return activitySubTitlePrizeId;
    }

    public void setActivitySubTitlePrizeId(Long activitySubTitlePrizeId) {
        this.activitySubTitlePrizeId = activitySubTitlePrizeId;
    }

    public Double getpPrizeRpm() {
        return pPrizeRpm;
    }

    public void setpPrizeRpm(Double pPrizeRpm) {
        this.pPrizeRpm = pPrizeRpm;
    }
}
